@@ -35,6 +35,21 @@ class DefaultLoader(getattr(yaml, 'CSafeLoader', yaml.SafeLoader)):  # type: ign
     pass
 
 
+# https://stackoverflow.com/a/37958106/2732151
+def remove_implicit_resolver(cls, tag_to_remove):
+    if 'yaml_implicit_resolvers' not in cls.__dict__:
+        cls.yaml_implicit_resolvers = cls.yaml_implicit_resolvers.copy()
+
+    for first_letter, mappings in cls.yaml_implicit_resolvers.items():
+        cls.yaml_implicit_resolvers[first_letter] = [
+            (tag, regexp) for tag, regexp in mappings if tag != tag_to_remove
+        ]
+
+
+remove_implicit_resolver(DefaultLoader, 'tag:yaml.org,2002:timestamp')
+remove_implicit_resolver(DefaultLoader, 'tag:yaml.org,2002:float')
+
+
 DefaultLoader.add_implicit_resolver(
     u'tag:yaml.org,2002:float',
     re.compile(u'''^(?:
