@@ -520,7 +520,7 @@ class SignatureArguments:
         doc_group = None
         doc_params = {}
         if docstring_parser_support:
-            docstring_parse, DocstringParseError = import_docstring_parse('_gather_docstrings')
+            docstring_parse, DocstringParseError = import_docstring_parse('_gather_docstrings', True)
             for base in objects:
                 for doc in docs_func(base):
                     try:
