@@ -87,8 +87,7 @@ leaf_types = {
     NoneType,
 }
 
-not_subclass_types: Set = set(k for k in registered_types.keys() if not isinstance(k, tuple))
-not_subclass_types = not_subclass_types.union(leaf_types).union(root_types)
+leaf_or_root_types = leaf_types.union(root_types)
 
 tuple_set_origin_types = {Tuple, tuple, Set, set, frozenset, MutableSet, abc.Set, abc.MutableSet}
 sequence_origin_types = {List, list, Iterable, Sequence, MutableSequence, abc.Iterable, abc.Sequence,
@@ -153,20 +152,23 @@ class ActionTypeHint(Action):
             getattr(typehint, '__origin__', None) in root_types or \
             typehint in registered_types or \
             _issubclass(typehint, Enum) or \
-            ActionTypeHint.is_class_typehint(typehint)
+            ActionTypeHint.is_subclass_typehint(typehint)
         if full and supported:
             typehint_origin = getattr(typehint, '__origin__', typehint)
-            if typehint_origin in root_types and typehint_origin != Literal:
+            if typehint not in root_types and typehint_origin in root_types and typehint_origin != Literal:
                 for typehint in getattr(typehint, '__args__', []):
-                    if typehint == Ellipsis or (typehint_origin == type and isinstance(typehint, TypeVar)):
-                        continue
-                    if not (typehint in leaf_types or ActionTypeHint.is_supported_typehint(typehint, full=True)):
+                    if not (
+                        typehint == Ellipsis or
+                        (typehint_origin == type and isinstance(typehint, TypeVar)) or
+                        typehint in leaf_types or
+                        ActionTypeHint.is_supported_typehint(typehint, full=True)
+                    ):
                         return False
         return supported
 
 
     @staticmethod
-    def is_class_typehint(typehint, only_subclasses=False, all_subtypes=True):
+    def is_subclass_typehint(typehint, all_subtypes=True):
         typehint = typehint_from_action(typehint)
         if typehint is None:
             return False
@@ -174,20 +176,14 @@ class ActionTypeHint(Action):
         if typehint_origin == Union:
             subtypes = [a for a in typehint.__args__ if a != NoneType]
             test = all if all_subtypes else any
-            return test(ActionTypeHint.is_class_typehint(s, only_subclasses) for s in subtypes)
-        if only_subclasses and is_final_class(typehint):
-            return False
+            return test(ActionTypeHint.is_subclass_typehint(s) for s in subtypes)
         return inspect.isclass(typehint) and \
-            typehint not in not_subclass_types and \
+            typehint not in leaf_or_root_types and \
+            typehint not in registered_types and \
             typehint_origin is None and \
             not _issubclass(typehint, (Path, Enum))
 
 
-    @staticmethod
-    def is_subclass_typehint(typehint, all_subtypes=True):
-        return ActionTypeHint.is_class_typehint(typehint, only_subclasses=True, all_subtypes=all_subtypes)
-
-
     @staticmethod
     def is_mapping_typehint(typehint):
         typehint_origin = getattr(typehint, '__origin__', typehint)
@@ -556,14 +552,6 @@ def adapt_typehints(val, typehint, serialize=False, instantiate_classes=False, p
             except (ImportError, AttributeError, ParserError) as ex:
                 raise ValueError(f'Type {typehint} expects a function or a callable class: {ex}')
 
-    # Final class
-    elif is_final_class(typehint):
-        if isinstance(val, dict):
-            val = Namespace(val)
-        if not isinstance(val, Namespace):
-            raise ValueError(f'Expected a Dict/Namespace but got "{val}"')
-        val = adapt_class_type(typehint, val, serialize, instantiate_classes, sub_add_kwargs)
-
     # Subclass
     elif not hasattr(typehint, '__origin__') and inspect.isclass(typehint):
         if isinstance(val, typehint):
