@@ -5,7 +5,9 @@ import re
 import uuid
 from datetime import timedelta
 from typing import Any, Callable, Dict, List, Optional, Pattern, Tuple, Type, Union
-from .util import import_object, Path
+from .namespace import Namespace
+from .optionals import typing_extensions_import
+from .util import Path
 
 
 __all__ = [
@@ -299,15 +301,17 @@ def add_type(type_class: Type, uniqueness_key: Optional[Tuple], type_check: Call
     register_type(type_class, type_class._type, **kwargs)  # type: ignore
 
 
-def final(cls):
-    """Decorator to make a class `final` meaning that it shouldn't be subclassed."""
-    setattr(cls, '_final_class', True)
-    return cls
+final = typing_extensions_import('final')
+if not getattr(final(Namespace()), '__final__', False):
+    def final(cls):  # pylint: disable=function-redefined
+        """Decorator to make a class `final`, i.e. it shouldn't be subclassed."""
+        setattr(cls, '__final__', True)
+        return cls
 
 
 def is_final_class(cls):
-    """Checks whether a class was decorated as `final`."""
-    return getattr(cls, '_final_class', False)
+    """Checks whether a class is final, i.e. decorated with ``final``."""
+    return getattr(cls, '__final__', False)
 
 
 PositiveInt        = restricted_number_type('PositiveInt',        int, ('>', 0),
@@ -338,29 +342,6 @@ register_type(complex)
 register_type(uuid.UUID)
 
 
-def get_import_path(value):
-    return value.__module__+'.'+value.__qualname__
-
-
-def object_path_serializer(value):
-    try:
-        path = get_import_path(value)
-        reimported = import_object(path)
-        if value is not reimported:
-            raise ValueError
-        return path
-    except Exception as ex:
-        raise ValueError(f'Only possible to serialize an importable object, given {value}: {ex}') from ex
-
-
-register_type(
-    Callable,
-    type_check=lambda v, t: callable(v),
-    serializer=object_path_serializer,
-    deserializer=lambda x: x if callable(x) else import_object(x),
-)
-
-
 def timedelta_deserializer(value):
     def raise_error():
         raise ValueError(f'Expected a string with form "h:m:s" or "d days, h:m:s" but got "{value}"')
