@@ -3,6 +3,7 @@
 import json
 import os
 import pathlib
+import random
 import re
 import sys
 import unittest
@@ -27,6 +28,7 @@ from jsonargparse.typing import (
     path_type,
     PositiveInt,
     register_type,
+    restricted_number_type,
 )
 from jsonargparse_tests.base import mock_module, TempDirTestCase
 
@@ -87,6 +89,13 @@ class TypeHintsTests(unittest.TestCase):
         self.assertIsNone(parser.parse_args(['--op=null']).op)
 
 
+    def test_str_not_timestamp_issue_135(self):
+        parser = ArgumentParser()
+        parser.add_argument('foo', type=str)
+        self.assertEqual('2022-04-12', parser.parse_args(['2022-04-12']).foo)
+        self.assertEqual('2022-04-32', parser.parse_args(['2022-04-32']).foo)
+
+
     def test_list(self):
         for list_type in [Iterable, List, Sequence]:
             with self.subTest(str(list_type)):
@@ -217,6 +226,21 @@ class TypeHintsTests(unittest.TestCase):
         self.assertEqual(parser.dump(cfg), 'complex: (2+3j)\n')
 
 
+    def test_restricted_number_type(self):
+        limit_val = random.randint(100, 10000)
+        larger_than = restricted_number_type(f'larger_than_{limit_val}', int, ('>', limit_val))
+
+        parser = ArgumentParser(error_handler=None)
+        parser.add_argument('--val', type=larger_than, default=limit_val+1, help='Description')
+
+        self.assertEqual(limit_val+1, parser.parse_args([f'--val={limit_val+1}']).val)
+        self.assertRaises(ParserError, lambda: parser.parse_args([f'--val={limit_val-1}']))
+
+        help_str = StringIO()
+        parser.print_help(help_str)
+        self.assertIn(f'Description (type: larger_than_{limit_val}, default: {limit_val+1})', help_str.getvalue())
+
+
     def test_type_Any(self):
         parser = ArgumentParser(error_handler=None)
         parser.add_argument('--any', type=Any)
@@ -248,6 +272,13 @@ class TypeHintsTests(unittest.TestCase):
         self.assertRaises(ParserError, lambda: parser.parse_args(['--false=true']))
 
 
+    def test_nested_mapping_without_args(self):
+        parser = ArgumentParser()
+        parser.add_argument('--map', type=Mapping[str, Union[int, Mapping]])
+        self.assertEqual(parser.parse_args(['--map={"a": 1}']).map, {"a": 1})
+        self.assertEqual(parser.parse_args(['--map={"b": {"c": 2}}']).map, {"b": {"c": 2}})
+
+
     def _test_typehint_non_parameterized_types(self, type):
         parser = ArgumentParser(error_handler=None)
         ActionTypeHint.is_supported_typehint(type, full=True)
